translate.misc.contextlib.GeneratorContextManager

Package translate :: Package misc :: Module contextlib :: Class GeneratorContextManager |
[hide private]
[frames] | no frames]

# Class GeneratorContextManager

source code

Helper for @contextmanager decorator.

Instance Methods | [hide private]
__init__(self, gen) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__enter__(self) | source code
__exit__(self, type, value, tb) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, gen) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)